@@ -10,7 +10,7 @@ after linearization, for example), but the reference ordering is as shown below.
 Example:
   raw = rawpipe.downsample(raw, iterations=2)
   raw = rawpipe.linearize(raw, blacklevel=64, whitelevel=1023)
-  rgb = rawpipe.wb(rgb, [1.5, 2.0])
+  rgb = rawpipe.wb(rgb, [1.5, 2.0], "RGGB")
   rgb = rawpipe.demosaic(raw, "RGGB")
   rgb = rawpipe.lsc(rgb, my_vignetting_map)
   rgb = rawpipe.lsc(rgb, my_color_shading_map)
@@ -39,5 +39,5 @@ _methods = [f for f in dir(Algorithms) if callable(getattr(Algorithms, f)) and n
 for m in _methods:
     globals()[m] = getattr(silent, m)
 
-__version__ = "0.11.0"
+__version__ = "0.12.0"
 __all__ = _methods
